# openapi-client
API for Zarban services.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import openapi_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import openapi_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import openapi_client
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.zarban.io
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://api.zarban.io"
)



# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.AccountsApi(api_client)
    address = '0x1234567890123456789012345678901234567890' # str | Ethereum address of the account

    try:
        # Get account by address
        api_response = api_instance.accounts_address_get(address)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AccountsApi->accounts_address_get: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *https://api.zarban.io*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountsApi* | [**accounts_address_get**](docs/AccountsApi.md#accounts_address_get) | **GET** /accounts/{address} | Get account by address
*AddressesApi* | [**addresses_get**](docs/AddressesApi.md#addresses_get) | **GET** /addresses | Get all addresses
*BorrowsApi* | [**lendingpool_borrows_get**](docs/BorrowsApi.md#lendingpool_borrows_get) | **GET** /lendingpool/borrows | Get user borrows of lendingpool
*CollectorApi* | [**stats_get**](docs/CollectorApi.md#stats_get) | **GET** /stats | Get collector data
*DepositsApi* | [**lendingpool_deposits_get**](docs/DepositsApi.md#lendingpool_deposits_get) | **GET** /lendingpool/deposits | Get user deposits of Lendingpool
*EventsApi* | [**events_get**](docs/EventsApi.md#events_get) | **GET** /events | Ordered list events based on query parameters
*IlksApi* | [**ilks_get**](docs/IlksApi.md#ilks_get) | **GET** /ilks | Get all Ilks
*IlksApi* | [**ilks_name_get**](docs/IlksApi.md#ilks_name_get) | **GET** /ilks/{name} | Get Ilk by name
*LendingPoolApi* | [**lendingpool_borrows_get**](docs/LendingPoolApi.md#lendingpool_borrows_get) | **GET** /lendingpool/borrows | Get user borrows of lendingpool
*LendingPoolApi* | [**lendingpool_deposits_get**](docs/LendingPoolApi.md#lendingpool_deposits_get) | **GET** /lendingpool/deposits | Get user deposits of Lendingpool
*LendingPoolApi* | [**lendingpool_overview_get**](docs/LendingPoolApi.md#lendingpool_overview_get) | **GET** /lendingpool/overview | Get lending pool overview
*LendingPoolApi* | [**lendingpool_reserves_get**](docs/LendingPoolApi.md#lendingpool_reserves_get) | **GET** /lendingpool/reserves | Fetch Reserve Data By Asset
*LendingPoolApi* | [**lendingpool_tx_borrow_post**](docs/LendingPoolApi.md#lendingpool_tx_borrow_post) | **POST** /lendingpool/tx/borrow | Borrow from lending pool
*LendingPoolApi* | [**lendingpool_tx_deposit_post**](docs/LendingPoolApi.md#lendingpool_tx_deposit_post) | **POST** /lendingpool/tx/deposit | Deposit to lending pool
*LendingPoolApi* | [**lendingpool_tx_repay_post**](docs/LendingPoolApi.md#lendingpool_tx_repay_post) | **POST** /lendingpool/tx/repay | Repay to lending pool
*LendingPoolApi* | [**lendingpool_tx_useassetascollateral_post**](docs/LendingPoolApi.md#lendingpool_tx_useassetascollateral_post) | **POST** /lendingpool/tx/useassetascollateral | Enable/Disable asset as collateral
*LendingPoolApi* | [**lendingpool_tx_withdraw_post**](docs/LendingPoolApi.md#lendingpool_tx_withdraw_post) | **POST** /lendingpool/tx/withdraw | Withdraw from lending pool
*OrdersApi* | [**orders_get**](docs/OrdersApi.md#orders_get) | **GET** /orders | Fetch Unfilled Orders
*OrdersApi* | [**orders_sync_post**](docs/OrdersApi.md#orders_sync_post) | **POST** /orders/sync | Updates Order Entity
*PermissionsApi* | [**permissions_matrix_get**](docs/PermissionsApi.md#permissions_matrix_get) | **GET** /permissions/matrix | Get authorization matrix
*PermitApi* | [**permit_single_get**](docs/PermitApi.md#permit_single_get) | **GET** /permit/single | Get permit for single token
*PricesApi* | [**prices_get**](docs/PricesApi.md#prices_get) | **GET** /prices | List prices based on query parameters
*PricesApi* | [**prices_symbol_history_get**](docs/PricesApi.md#prices_symbol_history_get) | **GET** /prices/{symbol}/history | Get price history for a symbol
*ProxiesApi* | [**proxies_get**](docs/ProxiesApi.md#proxies_get) | **GET** /proxies | Retrieves proxies owned by a specific owner
*StableCoinSystemApi* | [**ilks_get**](docs/StableCoinSystemApi.md#ilks_get) | **GET** /ilks | Get all Ilks
*StableCoinSystemApi* | [**ilks_name_get**](docs/StableCoinSystemApi.md#ilks_name_get) | **GET** /ilks/{name} | Get Ilk by name
*StableCoinSystemApi* | [**permissions_matrix_get**](docs/StableCoinSystemApi.md#permissions_matrix_get) | **GET** /permissions/matrix | Get authorization matrix
*StableCoinSystemApi* | [**proxies_get**](docs/StableCoinSystemApi.md#proxies_get) | **GET** /proxies | Retrieves proxies owned by a specific owner
*StableCoinSystemApi* | [**stablecoinsystem_tx_createvault_post**](docs/StableCoinSystemApi.md#stablecoinsystem_tx_createvault_post) | **POST** /stablecoinsystem/tx/createvault | Create vault
*StableCoinSystemApi* | [**stablecoinsystem_tx_depositcollateral_post**](docs/StableCoinSystemApi.md#stablecoinsystem_tx_depositcollateral_post) | **POST** /stablecoinsystem/tx/depositcollateral | Deposit collateral
*StableCoinSystemApi* | [**stablecoinsystem_tx_mintzar_post**](docs/StableCoinSystemApi.md#stablecoinsystem_tx_mintzar_post) | **POST** /stablecoinsystem/tx/mintzar | Mint ZAR
*StableCoinSystemApi* | [**stablecoinsystem_tx_repayzar_post**](docs/StableCoinSystemApi.md#stablecoinsystem_tx_repayzar_post) | **POST** /stablecoinsystem/tx/repayzar | Repay ZAR
*StableCoinSystemApi* | [**stablecoinsystem_tx_withdrawcollateral_post**](docs/StableCoinSystemApi.md#stablecoinsystem_tx_withdrawcollateral_post) | **POST** /stablecoinsystem/tx/withdrawcollateral | Withdraw collateral
*StableCoinSystemApi* | [**stats_get**](docs/StableCoinSystemApi.md#stats_get) | **GET** /stats | Get collector data
*StableCoinSystemApi* | [**vaults_get**](docs/StableCoinSystemApi.md#vaults_get) | **GET** /vaults | Get vaults by owner query
*StableCoinSystemApi* | [**vaults_id_events_get**](docs/StableCoinSystemApi.md#vaults_id_events_get) | **GET** /vaults/{id}/events | Get vault events by ID
*StableCoinSystemApi* | [**vaults_id_get**](docs/StableCoinSystemApi.md#vaults_id_get) | **GET** /vaults/{id} | Get a vault by ID
*SwapApi* | [**swap_quote_post**](docs/SwapApi.md#swap_quote_post) | **POST** /swap/quote | Get a quote for a swap
*VaultsApi* | [**vaults_get**](docs/VaultsApi.md#vaults_get) | **GET** /vaults | Get vaults by owner query
*VaultsApi* | [**vaults_id_events_get**](docs/VaultsApi.md#vaults_id_events_get) | **GET** /vaults/{id}/events | Get vault events by ID
*VaultsApi* | [**vaults_id_get**](docs/VaultsApi.md#vaults_id_get) | **GET** /vaults/{id} | Get a vault by ID
*WebsocketApi* | [**ws_get**](docs/WebsocketApi.md#ws_get) | **GET** /ws | Websocket Upgrade


## Documentation For Models

 - [Account](docs/Account.md)
 - [AccountLendingpoolSummary](docs/AccountLendingpoolSummary.md)
 - [AccountStablecoinSystemSummary](docs/AccountStablecoinSystemSummary.md)
 - [Address](docs/Address.md)
 - [AnswerUpdatedResponse](docs/AnswerUpdatedResponse.md)
 - [AuthMatrix](docs/AuthMatrix.md)
 - [Balance](docs/Balance.md)
 - [BasicEvent](docs/BasicEvent.md)
 - [BetterError](docs/BetterError.md)
 - [BetterErrorMessages](docs/BetterErrorMessages.md)
 - [ChainActivity](docs/ChainActivity.md)
 - [ChainActivityStep](docs/ChainActivityStep.md)
 - [ChainId](docs/ChainId.md)
 - [DutchAmount](docs/DutchAmount.md)
 - [EIP712SignRequest](docs/EIP712SignRequest.md)
 - [Error](docs/Error.md)
 - [EventDomain](docs/EventDomain.md)
 - [EventName](docs/EventName.md)
 - [EventType](docs/EventType.md)
 - [ExtendedEvent](docs/ExtendedEvent.md)
 - [ExtendedEventAllOf](docs/ExtendedEventAllOf.md)
 - [File](docs/File.md)
 - [FormattedReserveData](docs/FormattedReserveData.md)
 - [Ilk](docs/Ilk.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [LendingpoolBorrow](docs/LendingpoolBorrow.md)
 - [LendingpoolBorrowEvent](docs/LendingpoolBorrowEvent.md)
 - [LendingpoolBorrowTxRequest](docs/LendingpoolBorrowTxRequest.md)
 - [LendingpoolDeposit](docs/LendingpoolDeposit.md)
 - [LendingpoolDepositEvent](docs/LendingpoolDepositEvent.md)
 - [LendingpoolDepositTxRequest](docs/LendingpoolDepositTxRequest.md)
 - [LendingpoolFlashLoanEvent](docs/LendingpoolFlashLoanEvent.md)
 - [LendingpoolLiquidationCallEvent](docs/LendingpoolLiquidationCallEvent.md)
 - [LendingpoolRepayEvent](docs/LendingpoolRepayEvent.md)
 - [LendingpoolRepayTxRequest](docs/LendingpoolRepayTxRequest.md)
 - [LendingpoolStats](docs/LendingpoolStats.md)
 - [LendingpoolTxResponse](docs/LendingpoolTxResponse.md)
 - [LendingpoolUseAssetAsCollateralTxRequest](docs/LendingpoolUseAssetAsCollateralTxRequest.md)
 - [LendingpoolWithdrawEvent](docs/LendingpoolWithdrawEvent.md)
 - [LendingpoolWithdrawTxRequest](docs/LendingpoolWithdrawTxRequest.md)
 - [Log](docs/Log.md)
 - [MedianEvent](docs/MedianEvent.md)
 - [MethodParameters](docs/MethodParameters.md)
 - [Order](docs/Order.md)
 - [OrderInfo](docs/OrderInfo.md)
 - [OrderType](docs/OrderType.md)
 - [Permission](docs/Permission.md)
 - [PermitDetails](docs/PermitDetails.md)
 - [PermitSingle](docs/PermitSingle.md)
 - [PersonalSignRequest](docs/PersonalSignRequest.md)
 - [PreparedTx](docs/PreparedTx.md)
 - [Price](docs/Price.md)
 - [Proxy](docs/Proxy.md)
 - [QuoteRequest](docs/QuoteRequest.md)
 - [QuoteRequestOptions](docs/QuoteRequestOptions.md)
 - [QuoteResponse](docs/QuoteResponse.md)
 - [RawDutchAmount](docs/RawDutchAmount.md)
 - [StablecoinSystemCreateVaultTxRequest](docs/StablecoinSystemCreateVaultTxRequest.md)
 - [StablecoinSystemDepositCollateralTxRequest](docs/StablecoinSystemDepositCollateralTxRequest.md)
 - [StablecoinSystemMintZarTxRequest](docs/StablecoinSystemMintZarTxRequest.md)
 - [StablecoinSystemRepayZarTxRequest](docs/StablecoinSystemRepayZarTxRequest.md)
 - [StablecoinSystemStats](docs/StablecoinSystemStats.md)
 - [StablecoinSystemWithdrawCollateralTxRequest](docs/StablecoinSystemWithdrawCollateralTxRequest.md)
 - [Stats](docs/Stats.md)
 - [Symbol](docs/Symbol.md)
 - [TimeRange](docs/TimeRange.md)
 - [Timestamp](docs/Timestamp.md)
 - [Token](docs/Token.md)
 - [TradeType](docs/TradeType.md)
 - [Type](docs/Type.md)
 - [TypedData](docs/TypedData.md)
 - [TypedDataDomain](docs/TypedDataDomain.md)
 - [UpdateOrderRequest](docs/UpdateOrderRequest.md)
 - [V3PoolInRoute](docs/V3PoolInRoute.md)
 - [Vault](docs/Vault.md)
 - [VaultEvent](docs/VaultEvent.md)
 - [WalletBalance](docs/WalletBalance.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author




